# ReduxPY

Implementation of a Redux store with support for adding feature modules, dynamically. The store exposes a reactive API based on [RxPY](https://pypi.org/project/Rx/).

## Documentation

Refer to the [API documentation](https://reduxpy.readthedocs.io/en/latest/)

## Build

[![Build Status](https://travis-ci.org/Carsten-Leue/ReduxPY.svg?branch=master)](https://travis-ci.org/Carsten-Leue/ReduxPY)
